@@ -552,24 +552,6 @@ class SwitchboardBase(capability_base.CapabilityBase):
         RuntimeError: if LogWriterProcess is not available or running.
     """
 
-  @abc.abstractmethod
-  def transport_jlink_flash(self, image_path, port=0):
-    """Sends the flash command to the 'J-Link' transport.
-
-    Args:
-        image_path (str): path to the image file to be flashed onto the
-          device.
-        port (int): the transport port to send the command to.
-    """
-
-  @abc.abstractmethod
-  def transport_jlink_reset(self, port=0):
-    """Sends the reset command to the J - Link transport.
-
-    Args:
-        port(int): the transport port to send the command to.
-    """
-
   @abc.abstractmethod
   def transport_serial_set_baudrate(self, new_baudrate, port=0):
     """Sets the serial interface baudrate to a different baudrate.
@@ -591,14 +573,6 @@ class SwitchboardBase(capability_base.CapabilityBase):
         port(int or str): the transport port to open
     """
 
-  @abc.abstractmethod
-  def transport_serial_send_xoff(self, port=0):
-    """Sends the XOFF control character to the serial interface.
-
-    Args:
-        port(int or str): the transport port to open
-    """
-
   @abc.abstractmethod
   def transport_serial_send_break_byte(self, port=0):
     """Sends the break control character to the serial interface (Ctrl + C).
